.. _spkg_slabbe:

slabbe: Code for discrete dynamical systems, combinatorics, digital geometry
============================================================================

Description
-----------

This SageMath package contains various modules by Sébastien Labbé
for experimentation with

- discrete dynamical systems
- combinatorics
- digital geometry
- visualization
- miscellaneous development tools

License
-------

GPLv2+

Upstream Contact
----------------

- https://pypi.org/project/slabbe/
- https://github.com/passagemath/passagemath-pkg-slabbe


Type
----

optional


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- $(SAGERUNTIME)

Version Information
-------------------

requirements.txt::

    slabbe @ git+https://github.com/passagemath/passagemath-pkg-slabbe.git

Equivalent System Packages
--------------------------

# See https://repology.org/project/python:slabbe/versions

If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then ``./configure`` will check if the system package can be used.
